@@ -12,7 +12,7 @@ from tabulate import tabulate
 
 from ansible_bender.api import Application
 from ansible_bender.constants import ANNOTATIONS_KEY, PLAYBOOK_TEMPLATE
-from ansible_bender.core import PbVarsParser
+from ansible_bender.core import AnsibleVarsParser
 from ansible_bender.db import PATH_CANDIDATES
 from ansible_bender.okd import build_inside_openshift
 
@@ -124,6 +124,11 @@ class CLI:
             "--build-user",
             help="the container gets invoked with this user during build"
         )
+        self.build_parser.add_argument(
+            "--inventory",
+            help="path to Ansible inventory",
+            default=None,
+        )
         self.build_parser.add_argument(
             "--build-entrypoint",
             help="the container will be invoked with this entrypoint during the build"
@@ -178,6 +183,14 @@ class CLI:
             "--extra-buildah-from-args",
             help="arguments passed to buildah from command (be careful!)"
         )
+        self.build_parser.add_argument(
+            "--extra-buildah-run-args",
+            help="arguments passed to buildah run command (be careful!)"
+        )
+        self.build_parser.add_argument(
+            "--extra-podman-run-args",
+            help="arguments passed to podman run command (be careful!)"
+        )
         self.build_parser.add_argument(
             "--extra-ansible-args",
             help="arguments passed to ansible-playbook command (be careful!)"
@@ -281,7 +294,7 @@ class CLI:
         self.lb_parser.set_defaults(subcommand="clean")
 
     def _build(self):
-        pb_vars_p = PbVarsParser(self.args.playbook_path)
+        pb_vars_p = AnsibleVarsParser(self.args.playbook_path, self.args.inventory)
         build, metadata = pb_vars_p.get_build_and_metadata()
         build.metadata = metadata
         if self.args.workdir:
@@ -330,6 +343,10 @@ class CLI:
             build.squash = self.args.squash
         if self.args.extra_buildah_from_args:
             build.buildah_from_extra_args = self.args.extra_buildah_from_args
+        if self.args.extra_buildah_run_args:
+            build.buildah_run_extra_args = self.args.extra_buildah_run_args
+        if self.args.extra_podman_run_args:
+            build.podman_run_extra_args = self.args.extra_podman_run_args
         if self.args.extra_ansible_args:
             build.ansible_extra_args = self.args.extra_ansible_args
         if self.args.python_interpreter:
